#!/bin/bash
#
# name
#   ping.sh
#
# usage
#   ping.sh -h example.com
#
# author
#   JM Marino - 24 december 2009
#
# warning
#   /sbin/ping must be SetUID root to works fine with commom user
#     check 's' bit with this command:
#     ls -l `which ping`

BADARGS_ERR=1
PINGNOTFOUND_ERR=2
SETUID_ERR=3
PING_OK="OK"
PING_KO="KO"

# ----------------------------------------------------------
usage() {
  echo "Usage: $0 -h <host>"
  exit $BADARGS_ERR
}

# default ping command
# ----------------------------------------------------------
PING=`which ping`
if [ $? -ne 0 ]; then
  echo -n "ping not found!"
  exit $PINGNOTFOUND_ERR
fi

# check SetUID root for ping command
# ----------------------------------------------------------
if [ ! -u "$PING" ]; then
  echo -n "$PING must be SetUID root"
  exit $SETUID_ERR
fi

# check num args
# ----------------------------------------------------------
if [ $# -ne 2 ]; then
  usage
fi

# get options
# ----------------------------------------------------------
ARGS=`getopt h: $*`
if [ $? -ne 0 ]; then
  usage
fi
HOST=""
set -- $ARGS
for o
do	case "$o" in
	-h)	shift; HOST="$1"; shift;;
	--)	shift; break;;
	esac
done

# ----------------------------------------------------------
# MAIN
# ----------------------------------------------------------
$PING -n -c 1 $HOST >/dev/null 2>&1
if [ $? -eq 0 ]; then
	echo -n $PING_OK;
else
	echo -n $PING_KO;
fi
